import Image from "next/image";

import { Heart, ShoppingBag } from "lucide-react";

import { Button } from "@/components/ui/button";
import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";

import Progressbar from "../common/progress-bar";

interface ProductWithSalesItemProps {
	image: string;
	name: Record<Locale, string>;
	originalPrice: number;
	salePrice: number;
	stock: number;
	soldCount: number;
	totalCount: number;
	addToCart: Record<Locale, string>;
	addToFavorite: Record<Locale, string>;
	available: Record<Locale, string>;
	locale: Locale;
	isHighlighted?: boolean;
}

export function ProductWithSalesItem({
	image,
	name,
	originalPrice,
	salePrice,
	soldCount,
	totalCount,
	addToCart,
	addToFavorite,
	available,
	locale,
	isHighlighted,
}: ProductWithSalesItemProps) {
	const isRTL = locale === "ar";

	return (
		<div
			className={cn(
				"mx-auto flex items-center overflow-hidden rounded-lg px-4 py-3",
				isHighlighted ? "bg-[#2895C8]" : "bg-[#EEEDF1]"
			)}
		>
			{/* Product Details */}
			<div className="flex flex-1 flex-col gap-2 p-4">
				{/* Product Name */}
				<h3
					className={cn(
						"text-2xl font-medium",
						isRTL ? "text-right" : "text-left",
						isHighlighted ? "text-white" : "text-gray-900"
					)}
				>
					{name?.[locale]}
				</h3>

				{/* Pricing */}
				<div className={cn("flex items-center justify-start gap-1")}>
					<span
						className={cn(
							"relative text-sm line-through",
							isHighlighted ? "text-white" : "text-[#606676]"
						)}
					>
						${originalPrice.toFixed(2)}
					</span>
					-
					<span
						className={cn(
							"text-sm font-bold",
							isHighlighted ? "text-white" : "text-[#606676]"
						)}
					>
						${salePrice.toFixed(2)}
					</span>
				</div>

				{/* Stock Info */}
				<div
					className={cn(
						"text-sm",
						isRTL ? "text-right" : "text-left",
						isHighlighted ? "text-white/80" : "text-gray-600"
					)}
				>
					{`${available} t("Available")`}
				</div>

				{/* Progress Bar */}
				<div className="mb-2">
					<Progressbar
						progress={(soldCount / totalCount) * 100}
						progressColor="#FF7C02"
						height="h-5"
					/>
				</div>

				{/* Actions */}
				<div
					className={cn(
						"flex items-center justify-start gap-3",
						isRTL ? "flex-row-reverse" : "flex-row"
					)}
				>
					<Button
						variant="ghost"
						size="icon"
						className={cn(
							"h-10 w-10 rounded-full",
							"bg-white text-white hover:bg-custom-primary-accent"
						)}
						aria-label={addToFavorite?.[locale]}
					>
						<Heart className="h-5 w-5 text-custom-primary-accent" />
					</Button>
					<Button
						className={cn(
							"flex-1 gap-2 rounded-full p-6 px-5",
							isHighlighted
								? "hover:[#001C30]/90 bg-[#001C30] text-white"
								: "bg-[#606676] text-white hover:bg-[#606676]/90"
						)}
					>
						<ShoppingBag className="h-4 w-4" />
						{addToCart?.[locale]}
					</Button>
				</div>
			</div>

			{/* Product Image */}
			<div className="relative aspect-square w-40 shrink-0">
				<Image
					src={image}
					alt={name?.[locale]}
					fill
					className="rounded-md object-cover"
					priority
				/>
			</div>
		</div>
	);
}
